from breakout_bme68x import BreakoutBME68X
from pimoroni_i2c import PimoroniI2C
from breakout_rtc import BreakoutRTC
import time
import picodisplay

# Enregistrer la pression toutes les minutes => 3H au total environ
intervalle = 60

# Initialiser Picodisplay en créant un buffer pour l'affichage
# C'est dans ce buffer que seront dessinés les pixels
# update() envoie le buffer vers l'écran
buf = bytearray(picodisplay.get_width() * picodisplay.get_height() * 2)
picodisplay.init(buf)
picodisplay.set_backlight(1.0)

PINS_I2C = {"sda": 4, "scl": 5}
i2c = PimoroniI2C(**PINS_I2C)
bme = BreakoutBME68X(i2c)
rtc = BreakoutRTC(i2c)

if rtc.is_12_hour():
    rtc.set_24_hour()
 

picodisplay.set_pen(255, 0, 255)                  # Couleur CYAN
picodisplay.clear()                               # Effacer le buffer

picodisplay.set_led(255, 0, 0)   # Couleur ROUGE
time.sleep(1)                    # Attendre 1 seconde
picodisplay.set_led(0, 255, 0)   # Allumer LED en VERT
time.sleep(1)                    # Attendre 1 seconde
picodisplay.set_led(0, 0, 255)   # Allumer LED en BLEU


def jours(weekday):
    if weekday == 0:
        jour = "Lundi"
    if weekday == 1:
        jour = "Mardi"
    if weekday == 2:
        jour = "Mercredi"
    if weekday == 3:
        jour = "Jeudi"
    if weekday == 4:
        jour = "Vendredi"
    if weekday == 5:
        jour = "Samedi"
    if weekday == 6:
        jour = "Dimanche"
    return(jour)        
        

def picoclear():
    picodisplay.set_pen(0, 0, 255)
    picodisplay.clear()
    
# Créer liste pour pression 
var = []

time1 = time.time()    # Lire l'heure

while True:
    # Lire la date et l'heure
    if rtc.update_time():
        rtc_date = rtc.string_date()
        rtc_time = rtc.string_time()
        weekday = rtc.get_weekday()
    jour = jours(weekday)
    aff_date = str(jour) + " " + str(rtc_date)
    aff_time = str(rtc_time)
    
    # Lire les données du capteur
    temperature, pressure, humidity, gas_resistance, status, gas_index, meas_index = bme.read()
    # Formater température à 1 décimale
    temp = f'{temperature:.1f}'
    # Formater température à 1 décimale
    hum = f'{humidity:.1f}'+ ' %'
    pres = str(round(pressure/100, 2)) + ' mb'

    # Est ce le moment de mémoriser la pression ?
    if (time.time()-time1) > intervalle:
        # Gérer l'acquisition de pression
        if len(var) > 199:
            var.pop(0)
        var.append(int(pressure/100))
        #print(len(var))
        # Redémarrer le chrono
        time1 = time.time()

    picodisplay.set_pen(255, 255, 255)                
    picodisplay.text(aff_date, 10, 10, 240, 2)  
    picodisplay.text(aff_time, 10, 22, 240, 2)  

    picodisplay.text("P ", 120, 22, 240, 2)  
    picodisplay.text(str(int(pressure/100)), 140, 22, 240, 3)  

    picodisplay.text("T ", 10, 40, 240, 2)  
    picodisplay.text(str(temp), 30, 40, 240, 3) 

    picodisplay.text("H ", 120, 40, 240, 2)  
    picodisplay.text(str(hum), 140, 40, 240, 3)  

    # Tracer les axes
    # Trait milieu 1013 mb
    picodisplay.set_pen(120, 120, 120)                    # Couleur grise
    picodisplay.pixel_span(10,94,220)
    # Axe bas 
    picodisplay.set_pen(255, 255, 255)                    # Couleur blanche
    picodisplay.pixel_span(10,119,220)

    # Axe vertical
    for i in range (50):
        picodisplay.pixel(10,i+70) 
    # Afficher la courbe de pression
    # valeurs entre 993 et 1033
    # 1013 est affiché à 40 pixels du bas
    for i in range(len(var)):
        x=10+i
        y=(((var[i]-1013)*(-1))+75)
        picodisplay.pixel(x,y)

    # Affichage des infos
    picodisplay.update()

    ntime.sleep(0.2)
    picodisplay.set_pen(0, 0, 255)                    # Couleur BLEU
    picodisplay.clear()                               # Effacer le buffer

